# SPOT
![SPOT logo](doc/_static/spot-128x128.png)

Site Planning and Observation Tool (SPOT) 

[![Powered by Astropy Badge](http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat)](http://www.astropy.org)

## About

![SPOT screenshot](doc/screenshot-wd1200.png)

SPOT (Site Planning and Observation Tool) is a graphical tool for planning
and conducting astronomical observations at a site.  Here are few of the
things it can do:

- You can select a site and date/time when you plan to observe (it's also
  easy to add your own custom site).
- It can show you an astronomical almanac of information about a particular
  date (sunrise, sunset, moonrise, moonset, twilights, etc).
- It can load lists of targets and plot them on a polar plot for their
  position in the sky at the current time or any given time.
- It can show you the various targets' visibility as a plot of altitude
  vs. time.
- It can overlay fisheye-type sky camera images on the polar plot so that
  you can monitor for cloud coverage.
- With the right customization it can show you where your telescope target
  is, the current telescope position and the slew that it will take to get
  there on the polar plot.
- It can look up catalog images from various sources for a given target
  and show instrument detector overlays on top, with adjustable position
  angle.

## Installation

See the [quick installation instructions](INSTALL.md).



